@@ -1,7 +1,7 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Web/Content.pm 67717 2008-08-02T21:56:07.486475Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Web/Content.pm 102544 2009-03-19T08:58:09.853141Z daisuke  $
 
 package Data::Feed::Web::Content;
-use Moose;
+use Any::Moose;
 
 has 'type' => (
     is => 'rw',
@@ -15,7 +15,7 @@ has 'body' => (
 
 __PACKAGE__->meta->make_immutable;
 
-no Moose;
+no Any::Moose;
 
 1;
 
